@@ -1,6 +1,7 @@
 from regrex import linear_model
 from regrex import polynomial_model
 from regrex import preprocess
-from regrex import statistics
 from regrex import transform
-from regrex import prediction
\ No newline at end of file
+from regrex import dataset
+from regrex import statistics
+from regrex import validation
\ No newline at end of file
